@@ -14,13 +14,15 @@ class CoordSetTupleProvider(TuplesProviderABC):
         self._diagramPluginViewerApi = diagramPluginViewerApi
 
     @inlineCallbacks
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         coordSets = yield self._diagramPluginViewerApi.getCoordSets(
             modelSetKey=gisDiagramModelSetName
         )
 
-        payloadEnvelope = yield Payload(filt, tuples=coordSets).makePayloadEnvelopeDefer()
+        payloadEnvelope = yield Payload(
+            filt, tuples=coordSets
+        ).makePayloadEnvelopeDefer()
         vortexMsg = yield payloadEnvelope.toVortexMsgDefer()
         return vortexMsg
-
